@@ -167,6 +167,8 @@ class Photometry:
             Whether to redo the plot, even if it already exists
         """
 
+        logging.info("Computing the marginal plot for object ID: " + ID)
+
         if self.flux_units == 'milliJy':
             flux_factor = 1.E+03
             ylabel = "$f_{\\nu}/\\textnormal{mJy}$"
@@ -383,13 +385,14 @@ class Photometry:
 
                     # Redshift the SED and wl
                     flux_obs = SED / (1.+z)
-                    wl_obs = wl * (1.+z) / wl_factor
+                    wl_obs = wl * (1.+z)
 
                     # Convert F_lambda [erg s^-1 cm^-2 A^-1] ----> F_nu [erg s^-1 cm^-2 Hz^-1]
                     flux_obs = (wl_obs)**2/c_light*flux_obs
 
-                    # Scale to nanoJy
+                    # Scale to the correct flux and wl units
                     flux_obs = flux_obs / Jy * flux_factor
+                    wl_obs = wl_obs / wl_factor
 
                     prob = probability[i]
                     if SED_prob_log_scale:
@@ -559,7 +562,7 @@ class Photometry:
             name = prepare_plot_saving(plot_name)
 
             fig.savefig(name, dpi=None, facecolor='w', edgecolor='w',
-                    orientation='portrait', papertype='a4', format="pdf",
+                    orientation='portrait', format="pdf",
                     transparent=False, bbox_inches="tight", pad_inches=0.1)
 
         plt.close(fig)
@@ -763,7 +766,7 @@ class Photometry:
             name = prepare_plot_saving(str(ID)+'_BEAGLE_replic_data_phot_matrix.pdf')
 
             fig.savefig(name, dpi=None, facecolor='w', edgecolor='w',
-                    orientation='portrait', papertype='a4', format="pdf",
+                    orientation='portrait', format="pdf",
                     transparent=False, bbox_inches="tight", pad_inches=0.1)
 
             fig.clear()
@@ -955,7 +958,7 @@ class Photometry:
         name = prepare_plot_saving(plot_name)
 
         fig.savefig(name, dpi=None, facecolor='w', edgecolor='w',
-                orientation='portrait', papertype='a4', format="pdf",
+                orientation='portrait', format="pdf",
                 transparent=False, bbox_inches="tight", pad_inches=0.1)
 
         plt.close(fig)
