@@ -258,6 +258,8 @@ class Spectrum(object):
             Whether to print the object ID on the top of the plot.
         """
 
+        logging.info("Computing the marginal plot for object ID: " + ID)
+
         # Factor to convert angstrom to input units
         if self.wl_units == 'micron':
             wl_factor = 1.E+04
@@ -410,8 +412,10 @@ class Spectrum(object):
             _redshifts =  hdulist['galaxy properties'].data['redshift']
             _, _counts = np.unique(_redshifts, return_counts=True)
             if len(_counts) > 1:
-                raise ValueError("The `redshift` of the object is not unique!")
-            redshift = _redshifts[0]
+                logging.warning("The `redshift` of the object is not unique!")
+
+            # Take the MAP redshift
+            redshift = hdulist['galaxy properties'].data['redshift'][np.argmax(probability)]
 
         z1 = 1. + redshift
 
@@ -988,7 +992,7 @@ class Spectrum(object):
         name = prepare_plot_saving(plot_name)
 
         fig.savefig(name, dpi=None, facecolor='w', edgecolor='w',
-                orientation='portrait', papertype='a4', format="pdf",
+                orientation='portrait', format="pdf",
                 transparent=False, bbox_inches="tight", pad_inches=0.1)
         plt.close(fig)
 
