@@ -9,6 +9,7 @@ from bisect import bisect_left
 from scipy.integrate import simps, cumtrapz
 from scipy.interpolate import interp1d
 from datetime import datetime
+import platform
 
 import sys
 
@@ -99,7 +100,8 @@ def configure_matplotlib():
     # into 
     # mpl.rcParams['ytick.minor.right'] = True
 
-    mpl.rcParams['backend'] = 'MacOSX'
+    if platform.system() == 'Darwin':
+        mpl.rcParams['backend'] = 'MacOSX'
 
     mpl.rc('lines', 
             linewidth=1.5, linestyle='-', 
@@ -123,8 +125,6 @@ def configure_matplotlib():
     mpl.rcParams['text.latex.preamble'] = '\\usepackage{amssymb} \\usepackage{amsmath} \
             \\usepackage{upgreek} \\usepackage{txfonts} \\usepackage[utf8]{inputenc} \\DeclareUnicodeCharacter{2212}{$-$}'
 
-    mpl.rcParams['text.latex.preview'] = True
-
     mpl.rc('axes', 
             facecolor='white', edgecolor='black',
             linewidth=1.5, grid=False, labelpad=4.0,
